@@ -6,7 +6,7 @@ use Moose;
 use Padre::Plugin::Moose::FBP::Main ();
 use Padre::Wx::Role::Dialog         ();
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 our @ISA = qw{
 	Padre::Plugin::Moose::FBP::Main
@@ -37,6 +37,12 @@ sub new {
 	$preview->{Document} = Padre::Document->new( mimetype => 'application/x-perl', );
 	$preview->{Document}->set_editor($preview);
 	$preview->SetLexer('application/x-perl');
+
+	# Syntax highlight Moose keywords after get_indentation_style is called :)
+	# TODO remove hack once Padre supports a better way
+	require Padre::Plugin::Moose::Util;
+	Padre::Plugin::Moose::Util::add_moose_keywords_highlighting($preview->{Document});
+
 	$preview->Show(1);
 
 	$self->show_code_in_preview(1);
@@ -52,6 +58,8 @@ sub run {
 	my $style = $self->main->config->editor_style;
 	my $theme = Padre::Wx::Theme->find($style)->clone;
 	$theme->apply( $self->{preview} );
+
+	return;
 }
 
 # Set up the events
@@ -64,6 +72,8 @@ sub on_grid_cell_change {
 		if $element->does('Padre::Plugin::Moose::Role::CanHandleInspector');
 
 	$self->show_code_in_preview(0);
+
+	return;
 }
 
 sub on_tree_selection_change {
@@ -110,6 +120,8 @@ sub on_tree_selection_change {
 			$line_num++;
 		}
 	}
+
+	return;
 }
 
 sub show_code_in_preview {
@@ -137,6 +149,8 @@ sub show_code_in_preview {
 	};
 	$self->error( sprintf( Wx::gettext('Error:%s'), $@ ) )
 		if $@;
+
+	return;
 }
 
 sub update_tree {
@@ -199,6 +213,8 @@ sub update_tree {
 		)
 		if $should_select_item
 			&& defined $selected_item;
+
+	return;
 }
 
 sub show_inspector {
@@ -206,12 +222,12 @@ sub show_inspector {
 	my $element = shift;
 
 	unless ( defined $element ) {
-		$self->{inspector}->GetContainingSizer->Show(0);
+		$self->{inspector}->GetContainingSizer->Show( 0, 0 );
 		return;
 	}
 
 	my $type = blessed($element);
-	if ( ( not defined $type ) or ( $type !~ /(Class|Role|Attribute|Subtype|Method)$/ ) ) {
+	if ( ( not defined $type ) or ( $type !~ /(Class|Role|Attribute|Subtype|Method|Constructor|Destructor)$/ ) ) {
 		$self->error("type: $element is not Class, Role, Attribute, Subtype or Method\n");
 		return;
 	}
@@ -236,12 +252,14 @@ sub show_inspector {
 		$inspector->SetReadOnly( $row, 0 );
 	}
 
-	$self->{inspector}->GetContainingSizer->Show(1);
+	$self->{inspector}->GetContainingSizer->Show( 0, 1 );
 	$self->Layout;
 	$inspector->SetGridCursor( 0, 1 );
 
 	$element->write_to_inspector($inspector)
 		if $element->does('Padre::Plugin::Moose::Role::CanHandleInspector');
+
+	return;
 }
 
 sub on_add_class_button {
@@ -258,6 +276,8 @@ sub on_add_class_button {
 	$self->{current_element} = $class;
 	$self->show_inspector($class);
 	$self->show_code_in_preview(1);
+
+	return;
 }
 
 sub on_add_role_button {
@@ -272,6 +292,8 @@ sub on_add_role_button {
 	$self->{current_element} = $role;
 	$self->show_inspector($role);
 	$self->show_code_in_preview(1);
+
+	return;
 }
 
 sub on_add_attribute_button {
@@ -295,6 +317,8 @@ sub on_add_attribute_button {
 	$self->{current_element} = $attribute;
 	$self->show_inspector($attribute);
 	$self->show_code_in_preview(1);
+
+	return;
 }
 
 sub on_add_subtype_button {
@@ -318,6 +342,8 @@ sub on_add_subtype_button {
 	$self->{current_element} = $subtype;
 	$self->show_inspector($subtype);
 	$self->show_code_in_preview(1);
+
+	return;
 }
 
 sub on_add_method_button {
@@ -341,6 +367,8 @@ sub on_add_method_button {
 	$self->{current_element} = $method;
 	$self->show_inspector($method);
 	$self->show_code_in_preview(1);
+
+	return;
 }
 
 sub on_add_constructor_button {
@@ -355,15 +383,17 @@ sub on_add_constructor_button {
 		return;
 	}
 
-	# # Add a new constructor object to class
-	# require Padre::Plugin::Moose::Constructor;
-	# my $method = Padre::Plugin::Moose::Constructor->new;
-	# $method->name( 'method_' . $self->{method_count}++ );
-	# push @{ $self->{current_parent}->constructor }, $method;
+	# Add a new constructor object to class/role
+	require Padre::Plugin::Moose::Constructor;
+	my $constructor = Padre::Plugin::Moose::Constructor->new;
+	$constructor->name('BUILD');
+	push @{ $self->{current_parent}->methods }, $constructor;
 
-	# $self->{current_element} = $method;
-	# $self->show_inspector($method);
-	# $self->show_code_in_preview(1);
+	$self->{current_element} = $constructor;
+	$self->show_inspector($constructor);
+	$self->show_code_in_preview(1);
+
+	return;
 }
 
 sub on_add_destructor_button {
@@ -378,15 +408,17 @@ sub on_add_destructor_button {
 		return;
 	}
 
-	# # Add a new destructor object to class
-	# require Padre::Plugin::Moose::Destructor;
-	# my $method = Padre::Plugin::Moose::Destructor->new;
-	# $method->name( 'method_' . $self->{method_count}++ );
-	# push @{ $self->{current_parent}->methods }, $method;
+	# Add a new destructor object to class/role
+	require Padre::Plugin::Moose::Destructor;
+	my $destructor = Padre::Plugin::Moose::Destructor->new;
+	$destructor->name('DEMOLISH');
+	push @{ $self->{current_parent}->methods }, $destructor;
 
-	# $self->{current_element} = $method;
-	# $self->show_inspector($method);
-	# $self->show_code_in_preview(1);
+	$self->{current_element} = $destructor;
+	$self->show_inspector($destructor);
+	$self->show_code_in_preview(1);
+
+	return;
 }
 
 sub on_use_mouse_checkbox {
@@ -408,6 +440,8 @@ sub on_reset_button_clicked {
 		$self->restore_defaults;
 		$self->show_code_in_preview(1);
 	}
+
+	return;
 }
 
 sub on_generate_code_button_clicked {
@@ -424,6 +458,8 @@ sub on_generate_code_button_clicked {
 	);
 
 	$self->EndModal(Wx::ID_OK);
+
+	return;
 }
 
 sub restore_defaults {
@@ -443,6 +479,8 @@ sub restore_defaults {
 	# Defaults
 	$self->{comments_checkbox}->SetValue(1);
 	$self->{sample_code_checkbox}->SetValue(1);
+
+	return;
 }
 
 # Called when a item context menu is requested.
@@ -509,9 +547,7 @@ sub delete_element {
 }
 
 sub on_generated_code_combo {
-	my $self = shift;
-
-	$self->show_code_in_preview(1);
+	$_[0]->show_code_in_preview(1);
 }
 
 1;
